/*
* Blocks struct
*/

#ifndef __BLOCK_H__
#define __BLOCK_H__

#include <stdio.h>
#include "gameField.h"

// Block rotation enum
#define BLOCK_ROTATION_NORTH	1
#define BLOCK_ROTATION_EAST	2
#define BLOCK_ROTATION_SOUTH	3
#define BLOCK_ROTATION_WEST	4

// Block type enum
#define BLOCK_TYPE_UNDEFINED	0
#define BLOCK_TYPE_SQUARE		1
#define BLOCK_TYPE_LINE		2
#define BLOCK_TYPE_J			3
#define BLOCK_TYPE_L			4
#define BLOCK_TYPE_T			5
#define BLOCK_TYPE_Z			6
#define BLOCK_TYPE_S			7

// Block struct
typedef struct {
	
	// location
	VECTOR *m_Location;

	// Square size
	int m_SquareSize;
	
	// Block rotation
	int m_Rotation;
	
	// Block type
	int m_Type;
		
	// squares
	Square *m_Square1;
	Square *m_Square2;
	Square *m_Square3;
	Square *m_Square4;
} Block;

// Create block
Block *block_new(VECTOR *location, int type)
{
	// Nouvelle structure de bloc
	Block *block = (Block *) malloc(sizeof(Block));
	
	// Renseigner les pointeurs
	block->m_Location = (VECTOR *)malloc(sizeof(VECTOR));
	vec_set(block->m_Location, location);
	
	block->m_Location.x += START_X;
	block->m_Location.y += START_Y;
		
	// square size
	block->m_SquareSize = SQUARE_SIZE;
	
	// Rotation
	block->m_Rotation = BLOCK_ROTATION_NORTH;
	
	// crer un block alatoire si le type est indfini
	if (type == BLOCK_TYPE_UNDEFINED)
	{
		random_seed(0);
		int randType = random(8);
		// control
		if(randType > 7)
			randType = 7;
		else if (randType <= 0) {
			randType = 1;
		}
		block->m_Type = randType;
	}
	else
	{
		block->m_Type = type;
	}
	
	// Couleurs
	VECTOR *c1 = blockColors[block->m_Type - 1][0];
	VECTOR *c2 = blockColors[block->m_Type - 1][1];
	
	// squares
	block->m_Square1 = square_new(block->m_SquareSize, c1, c2, nullvector);
	block->m_Square2 = square_new(block->m_SquareSize, c1, c2, nullvector);
	block->m_Square3 = square_new(block->m_SquareSize, c1, c2, nullvector);
	block->m_Square4 = square_new(block->m_SquareSize, c1, c2, nullvector);
	
	// Position des squares
	switch(block->m_Type)
	{
		// Carr
		case BLOCK_TYPE_SQUARE:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y + block->m_SquareSize, 0));
			break;
		// Ligne
		case BLOCK_TYPE_LINE:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize * 2, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize * 3, 0));
			break;
		case BLOCK_TYPE_J:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize * 2, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x - block->m_SquareSize, block->m_Location.y + block->m_SquareSize * 2, 0));
			break;
		case BLOCK_TYPE_L:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize * 2, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y + block->m_SquareSize * 2, 0));
			break;
		case BLOCK_TYPE_T:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x + block->m_SquareSize * 2, block->m_Location.y, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y + block->m_SquareSize, 0));
			break;
		case BLOCK_TYPE_Z:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x + block->m_SquareSize * 2, block->m_Location.y + block->m_SquareSize, 0));
			break;
		case BLOCK_TYPE_S:
			vec_set(block->m_Square1->m_Location, vector(block->m_Location.x, block->m_Location.y, 0));
			vec_set(block->m_Square2->m_Location, vector(block->m_Location.x + block->m_SquareSize, block->m_Location.y, 0));
			vec_set(block->m_Square3->m_Location, vector(block->m_Location.x, block->m_Location.y + block->m_SquareSize, 0));
			vec_set(block->m_Square4->m_Location, vector(block->m_Location.x - block->m_SquareSize, block->m_Location.y + block->m_SquareSize, 0));
			break;
	}
	
	// Retourner le bloc cre
	return block;
}

// draw block
void block_draw(Block *block)
{
	// Quitter s'il n'y a pas de block
	if (block == NULL)
		return;
	// Test des squares
	square_draw(block->m_Square1);
	square_draw(block->m_Square2);
	square_draw(block->m_Square3);
	square_draw(block->m_Square4);
}

// dplcer un bloc une case en bas
BOOL block_down(Block *block)
{
	Square *square1 = block->m_Square1;
	Square *square2 = block->m_Square2;
	Square *square3 = block->m_Square3;
	Square *square4 = block->m_Square4;
	
	int squareSize = block->m_SquareSize; 
	
	// Tester si l'emplacement est vide
	if(gameField_isEmpty((square1->m_Location.x - START_X) / squareSize, ((square1->m_Location.y - START_Y) / squareSize)+1)
		&& gameField_isEmpty((square2->m_Location.x - START_X) / squareSize, ((square2->m_Location.y - START_Y) / squareSize)+1)
		&& gameField_isEmpty((square3->m_Location.x - START_X) / squareSize, ((square3->m_Location.y - START_Y) / squareSize)+1)
		&& gameField_isEmpty((square4->m_Location.x - START_X) / squareSize, ((square4->m_Location.y - START_Y) / squareSize)+1)
	)
	{
		// Dplacer les cases vers le bas
		square1->m_Location.y += block->m_SquareSize;
		square2->m_Location.y += block->m_SquareSize;
		square3->m_Location.y += block->m_SquareSize;
		square4->m_Location.y += block->m_SquareSize;
		
		block->m_Location.y += block->m_SquareSize;
		
		// return true
		return TRUE;
	}
	else
	{
		// Stopper les carres
		gameField_stopSquare(square1, (square1->m_Location.x - START_X) / squareSize, (square1->m_Location.y - START_Y) / squareSize);
		gameField_stopSquare(square2, (square2->m_Location.x - START_X) / squareSize, (square2->m_Location.y - START_Y) / squareSize);
		gameField_stopSquare(square3, (square3->m_Location.x - START_X) / squareSize, (square3->m_Location.y - START_Y) / squareSize);
		gameField_stopSquare(square4, (square4->m_Location.x - START_X) / squareSize, (square4->m_Location.y - START_Y) / squareSize);
		
		return FALSE;
	}
}

// dplcer un bloc une case en  gauche
BOOL block_left(Block *block)
{
	Square *square1 = block->m_Square1;
	Square *square2 = block->m_Square2;
	Square *square3 = block->m_Square3;
	Square *square4 = block->m_Square4;
	
	int squareSize = block->m_SquareSize; 
	
	// Tester si l'emplacement est vide
	if(gameField_isEmpty(((square1->m_Location.x - START_X) / squareSize)-1, (square1->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square2->m_Location.x - START_X) / squareSize)-1, (square2->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square3->m_Location.x - START_X) / squareSize)-1, (square3->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square4->m_Location.x - START_X) / squareSize)-1, (square4->m_Location.y - START_Y) / squareSize)
	)
	{
		// Dplacer les cases vers le bas
		square1->m_Location.x -= block->m_SquareSize;
		square2->m_Location.x -= block->m_SquareSize;
		square3->m_Location.x -= block->m_SquareSize;
		square4->m_Location.x -= block->m_SquareSize;
		
		// return true
		return TRUE;
	}
	
	// return false
	return FALSE;
}

// dplcer un bloc une case en  droite
BOOL block_right(Block *block)
{
	Square *square1 = block->m_Square1;
	Square *square2 = block->m_Square2;
	Square *square3 = block->m_Square3;
	Square *square4 = block->m_Square4;
	
	int squareSize = block->m_SquareSize; 
	
	// Tester si l'emplacement est vide
	if(gameField_isEmpty(((square1->m_Location.x - START_X) / squareSize)+1, (square1->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square2->m_Location.x - START_X) / squareSize)+1, (square2->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square3->m_Location.x - START_X) / squareSize)+1, (square3->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty(((square4->m_Location.x - START_X) / squareSize)+1, (square4->m_Location.y - START_Y) / squareSize)
	)
	{
		// Dplacer les cases vers le bas
		square1->m_Location.x += block->m_SquareSize;
		square2->m_Location.x += block->m_SquareSize;
		square3->m_Location.x += block->m_SquareSize;
		square4->m_Location.x += block->m_SquareSize;
		
		// return true
		return TRUE;
	}
	
	// return false
	return FALSE;
}

// rotation d'un bloc
BOOL block_rotate(Block *block)
{
	// Block squares
	Square *square1 = block->m_Square1;
	Square *square2 = block->m_Square2;
	Square *square3 = block->m_Square3;
	Square *square4 = block->m_Square4;
	
	int squareSize = block->m_SquareSize;
	
	// Sauvegarder les positions actuels des blocks
	int x1 = square1->m_Location.x, y1 = square1->m_Location.y;
	int x2 = square2->m_Location.x, y2 = square2->m_Location.y;
	int x3 = square3->m_Location.x, y3 = square3->m_Location.y;
	int x4 = square4->m_Location.x, y4 = square4->m_Location.y;
	
	// Dernier statut de rotation
	int oldRotationStatus = block->m_Rotation;
	
	// Tourner les blocks
	switch(block->m_Type) {
		// Carr
		case BLOCK_TYPE_SQUARE:
			// No rotation
			break;
		// Ligne
		case BLOCK_TYPE_LINE:
			// 2 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square1->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x + block->m_SquareSize * 2, square2->m_Location.y, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize * 2, 0));
					break;
			}
			break;
		case BLOCK_TYPE_J:
				// 4 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x + block->m_SquareSize * 2, square2->m_Location.y, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_SOUTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize * 2, 0));
					break;
				// Position 3
				case BLOCK_ROTATION_SOUTH:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_WEST;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x - block->m_SquareSize * 2, square2->m_Location.y, 0));
					break;
				// Position 4
				case BLOCK_ROTATION_WEST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize * 2, 0));
					break;
			}
			break;
		case BLOCK_TYPE_L:
			// 4 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square1->m_Location, vector(square3->m_Location.x + block->m_SquareSize * 2, square3->m_Location.y, 0));
					vec_set(square2->m_Location, vector(square3->m_Location.x + block->m_SquareSize, square3->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square3->m_Location.x, square3->m_Location.y + block->m_SquareSize, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_SOUTH;
					// Position
					vec_set(square1->m_Location, vector(square3->m_Location.x, square3->m_Location.y + block->m_SquareSize * 2, 0));
					vec_set(square2->m_Location, vector(square3->m_Location.x, square3->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square3->m_Location.x - block->m_SquareSize, square3->m_Location.y, 0));
					break;
				// Position 3
				case BLOCK_ROTATION_SOUTH:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_WEST;
					// Position
					vec_set(square1->m_Location, vector(square3->m_Location.x - block->m_SquareSize * 2, square3->m_Location.y, 0));
					vec_set(square2->m_Location, vector(square3->m_Location.x - block->m_SquareSize, square3->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square3->m_Location.x, square3->m_Location.y - block->m_SquareSize, 0));
					break;
				// Position 4
				case BLOCK_ROTATION_WEST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square1->m_Location, vector(square3->m_Location.x, square3->m_Location.y - block->m_SquareSize * 2, 0));
					vec_set(square2->m_Location, vector(square3->m_Location.x, square3->m_Location.y - block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square3->m_Location.x + block->m_SquareSize, square3->m_Location.y, 0));
					break;
			}
			break;
		case BLOCK_TYPE_T:
			// 4 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_SOUTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					break;
				// Position 3
				case BLOCK_ROTATION_SOUTH:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_WEST;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					break;
				// Position 4
				case BLOCK_ROTATION_WEST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					break;
			}
			break;
		case BLOCK_TYPE_Z:
				// 2 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square1->m_Location, vector(square2->m_Location.x, square2->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y + block->m_SquareSize, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square1->m_Location, vector(square2->m_Location.x - block->m_SquareSize, square2->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square2->m_Location.x, square2->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square2->m_Location.x + block->m_SquareSize, square2->m_Location.y + block->m_SquareSize, 0));
					break;
			}
			break;
		case BLOCK_TYPE_S:
				// 2 types de rotation
			switch(block->m_Rotation) {
				// Position 1
				case BLOCK_ROTATION_NORTH:
					// Modifier la rotation en cours
					block->m_Rotation = BLOCK_ROTATION_EAST;
					// Position des squares
					vec_set(square2->m_Location, vector(square1->m_Location.x, square1->m_Location.y - block->m_SquareSize, 0));
					vec_set(square3->m_Location, vector(square1->m_Location.x + block->m_SquareSize, square1->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square1->m_Location.x + block->m_SquareSize, square1->m_Location.y, 0));
					break;
				// Position 2
				case BLOCK_ROTATION_EAST:
					// Rotation = NORTH
					block->m_Rotation = BLOCK_ROTATION_NORTH;
					// Position
					vec_set(square2->m_Location, vector(square1->m_Location.x + block->m_SquareSize, square1->m_Location.y, 0));
					vec_set(square3->m_Location, vector(square1->m_Location.x - block->m_SquareSize, square1->m_Location.y + block->m_SquareSize, 0));
					vec_set(square4->m_Location, vector(square1->m_Location.x, square1->m_Location.y + block->m_SquareSize, 0));
					break;
			}
			break;
	}
	
	// Tester si les nouvelles positions sont valides
	// Retourner  la position initiale sinon
	if(!(gameField_isEmpty((square1->m_Location.x - START_X) / squareSize, (square1->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty((square2->m_Location.x - START_X) / squareSize, (square2->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty((square3->m_Location.x - START_X) / squareSize, (square3->m_Location.y - START_Y) / squareSize)
		&& gameField_isEmpty((square4->m_Location.x - START_X) / squareSize, (square4->m_Location.y - START_Y) / squareSize)
	))
	{
		// Retourner aux position d'origines
		square1->m_Location.x = x1; square1->m_Location.y = y1;
		square2->m_Location.x = x2; square2->m_Location.y = y2;
		square3->m_Location.x = x3; square3->m_Location.y = y3;
		square4->m_Location.x = x4; square4->m_Location.y = y4;
		
		// Dernire rotation
		block->m_Rotation = oldRotationStatus;
		
		// return false
		return FALSE;
	}
	
	// Return true
	return TRUE;
}

// Tester si le blocke est en haut
BOOL block_isTop(Block *block)
{
	// Block squares
	Square *square1 = block->m_Square1;
	Square *square2 = block->m_Square2;
	Square *square3 = block->m_Square3;
	Square *square4 = block->m_Square4;
	
	// SquareSize
	int squareSize = block->m_SquareSize;
	
	if(gameField_isSquareTop((square1->m_Location.y - START_Y) / squareSize)
		|| gameField_isSquareTop((square2->m_Location.y - START_Y) / squareSize)
		|| gameField_isSquareTop((square3->m_Location.y - START_Y) / squareSize)
		|| gameField_isSquareTop((square4->m_Location.y - START_Y) / squareSize)
	)
	{		
		// return true
		return TRUE;
	}
	return FALSE;
}

// __BLOCK_H__
#endif
